@@ -17,7 +17,7 @@ sub analyse {
     my $distdir=$me->distdir;
     my $modules=$me->d->{modules};
     my $files=$me->d->{files_array};
-    my @tests=grep {m|^t/|} @$files;
+    my @tests=grep {m|^t/.*\.t|} @$files;
     
     my %skip=map {$_->{module}=>1 } @$modules;
     my %uses;
@@ -40,6 +40,7 @@ sub analyse {
     # used in tests
     my $pt=Module::ExtractUse->new;
     foreach my $tf (@tests) {
+        next if -s catfile($distdir,$tf) > 1_000_000; # skip very large test files
         $pt->extract_use(catfile($distdir,$tf));
     }
     while (my ($mod,$cnt)=each%{$pt->used}) {
@@ -69,6 +70,7 @@ sub kwalitee_indicators {
             name=>'use_strict',
             error=>q{This distribution does not use 'strict' in all of its modules.},
             remedy=>q{Add 'use strict' to all modules.},
+            # TODO report errors
             code=>sub {
                 my $d=shift;
                 my $modules=$d->{modules};
